# CobraGPT

CobraGPT is an interface for routing/chaining outbound API requests to various endpoints asynchronously and parsing/formatting the output.

## Currently Supported Endpoints:

**API**
- Atera *(in progress)*
- ClickUp *(in progress)*
- Google *(Search / SiteSearch)*

**GPT**
- OpenAI
- Replicate

**Scraping**
- Frase
- ModestMoney
- TrustPilot

## Currently Supported Format Conversions:

- JSON
- PDF *(in progress)*
- HTML
- Markdown
- Plaintext
- DocX *(in progress)*

## References:
- [Atera](https://app.atera.com/apidocs)
- [ClickUp](https://clickup.com/api/clickupreference/)
- [Google Search](https://developers.google.com/custom-search/v1/overview)

- [OpenAI](https://platform.openai.com/docs/api-reference)
- [Replicate](https://replicate.com/docs/reference/http)

- [Frase](https://www.frase.io/)
- [Modest Money](https://modestmoney.com)
- [TrustPilot](https://trustpilot.com)

- [ReportLab PDF](https://www.reportlab.com/docs/reportlab-userguide.pdf)
- [python-docx](https://github.com/python-openxml/python-docx)
- [markdown](https://github.com/Python-Markdown/markdown)
